@@ -151,13 +151,13 @@ class BitmexOrder:
             self.props[symbol] = {
                 'stoploss_id': '', 'stop_id': '', 'entry': .0, 'SL': .0, 'TP': .0, 'open': False, 'wait_stop': False, 'qty': 0}
 
-        self.show_slippage = False # only for testing
+        self.show_slippage = False  # only for testing
         if self.show_slippage:
             self.entry_acc_balance = {}
             self.between_profits = {}
             for symbol in symbols:
-                        self.between_profits[symbol] = .0
-                        self.entry_acc_balance[symbol] = .0
+                self.between_profits[symbol] = .0
+                self.entry_acc_balance[symbol] = .0
 
     def check_open_bot_order(self, symbol, entry, sl):
         settings = pickle.load(open(self._settings_path, 'rb'))
@@ -195,7 +195,7 @@ class BitmexOrder:
             self.props[symbol]['stop_id'] = id
             settings.symbols[symbol]['last_order_stop_id'] = id
             pickle.dump(settings, file=open(self._settings_path, 'wb'))
-        elif stop_type == 'stoploss': # also save the stoploss
+        elif stop_type == 'stoploss':  # also save the stoploss
             self.props[symbol]['stoploss_id'] = id
             settings.symbols[symbol]['last_order_stoploss_id'] = id
             settings.symbols[symbol]['last_order_SL'] = self.props[symbol]['SL']
@@ -228,7 +228,8 @@ class BitmexOrder:
                                                                                             exitPrice,
                                                                                             pnl_points), flush=True)
         if self.show_slippage and self.props[symbol]['initialSL']:
-            acc_pos_size = float(self.settings.symbols[symbol]['position_size'])/100
+            acc_pos_size = float(
+                self.settings.symbols[symbol]['position_size'])/100
 
             current_acc_balance = float(self.client.acc_balance)
 
@@ -239,18 +240,24 @@ class BitmexOrder:
                     self.between_profits[sym] = .0
 
             # real acc balance difference counting the between profits
-            acc_balance_diff = self.entry_acc_balance[symbol] - current_acc_balance + between_profs
-            
-            self.between_profits[symbol] += acc_balance_diff # in acc balance difference
+            acc_balance_diff = self.entry_acc_balance[symbol] - \
+                current_acc_balance + between_profs
 
-            initial_risk_points = abs(self.props[symbol]['initialSL'] - self.props[symbol]['entry'])
+            # in acc balance difference
+            self.between_profits[symbol] += acc_balance_diff
+
+            initial_risk_points = abs(
+                self.props[symbol]['initialSL'] - self.props[symbol]['entry'])
             pnl_rr = pnl_points / initial_risk_points
-            
-            pnl_rel_expected = self.entry_acc_balance[symbol] * (1 + (pnl_rr * acc_pos_size))
-            pnl_rel_real = self.entry_acc_balance[symbol] * (1 + (acc_balance_diff / self.entry_acc_balance[symbol]))
+
+            pnl_rel_expected = self.entry_acc_balance[symbol] * (
+                1 + (pnl_rr * acc_pos_size))
+            pnl_rel_real = self.entry_acc_balance[symbol] * (
+                1 + (acc_balance_diff / self.entry_acc_balance[symbol]))
 
             # slippage is real acc balance change relative - exepceted pnl percent
-            print("Slippage: {}%".format(round((pnl_rel_real - pnl_rel_expected) * 100,2)),flush=True)
+            print("Slippage: {}%".format(
+                round((pnl_rel_real - pnl_rel_expected) * 100, 2)), flush=True)
             self.entry_acc_balance[symbol] = current_acc_balance
         self.props[symbol]['qty'] = 0
 
@@ -280,6 +287,8 @@ class BitmexOrder:
         for symbol in symbols:
             if not candlePrice:
                 cp = self.client.get_current_price(symbol)
+            else:
+                cp = ''
             time.sleep(0.5)
             if self.props[symbol]['wait_stop']:
                 self.has_position_opened(symbol, cp, candlePrice)
@@ -291,10 +300,10 @@ class BitmexOrder:
             if self.props[symbol]['qty'] > 0:
                 candlePrice = self.client.get_current_price_candle(symbol)
                 # + 1 to prevent endless loop
-                self.manage_entries(self._symbols, candlePrice=cp)
+                self.manage_entries(self._symbols, candlePrice=candlePrice)
             elif self.props[symbol]['qty'] < 0:
                 candlePrice = self.client.get_current_price_candle(symbol)
-                self.manage_entries(self._symbols, candlePrice=cp)
+                self.manage_entries(self._symbols, candlePrice=candlePrice)
 
     def generate_id(self, symbol, _type='stop'):
         return "{}_{}_{}_{}".format(self.magic, symbol, str(uuid.uuid4().fields[-1])[:5], _type)
